OutputDirName

Enum OutputDirName 

pub enum OutputDirName {
    CurrentDir,
    Custom(String),
}
The name of the directory where the log file is written to. Only applies if LoggingMode is File or FileAndConsole. Defaults to Custom with the output directory being logs.

Variants



CurrentDir

The log file is written to the current directory.



Custom(String)

The log file is written to a directory specified by the user.